SF: Update backdoor permissions check constant

Update the permissions check on backdoor calls to allow
for code 1029 which was recently added.

Test: None
Change-Id: I7b160bc55799633b9a973c347acc4131760df513
diff --git a/services/surfaceflinger/SurfaceFlinger.cpp b/services/surfaceflinger/SurfaceFlinger.cpp
index feab5eb..4b95036 100644
--- a/services/surfaceflinger/SurfaceFlinger.cpp
+++ b/services/surfaceflinger/SurfaceFlinger.cpp
@@ -4636,9 +4636,9 @@
     if (code == IBinder::INTERFACE_TRANSACTION) {
         return OK;
     }
     // Numbers from 1000 to 1028 are currently use for backdoors. The code
     // in onTransact verifies that the user is root, and has access to use SF.
-    if (code >= 1000 && code <= 1028) {
+    if (code >= 1000 && code <= 1029) {
         ALOGV("Accessing SurfaceFlinger through backdoor code: %u", code);
         return OK;
     }
@@ -4636,9 +4636,9 @@
         return OK;
     }
-    // Numbers from 1000 to 1028 are currently use for backdoors. The code
+    // Numbers from 1000 to 1029 are currently use for backdoors. The code
     // in onTransact verifies that the user is root, and has access to use SF.